summaryrefslogtreecommitdiffstats
path: root/src/kernel/qimage.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/kernel/qimage.cpp')
-rw-r--r--src/kernel/qimage.cpp46
1 files changed, 23 insertions, 23 deletions
diff --git a/src/kernel/qimage.cpp b/src/kernel/qimage.cpp
index edc77a85..56bd482e 100644
--- a/src/kernel/qimage.cpp
+++ b/src/kernel/qimage.cpp
@@ -38,24 +38,24 @@
**
**********************************************************************/
-#include "qimage.h"
-#include "qregexp.h"
-#include "qfile.h"
-#include "qdatastream.h"
-#include "qtextstream.h"
-#include "qbuffer.h"
-#include "qptrlist.h"
-#include "qasyncimageio.h"
-#include "qpngio.h"
-#include "qmngio.h"
-#include "qjpegio.h"
-#include "qmap.h"
+#include "ntqimage.h"
+#include "ntqregexp.h"
+#include "ntqfile.h"
+#include "ntqdatastream.h"
+#include "ntqtextstream.h"
+#include "ntqbuffer.h"
+#include "ntqptrlist.h"
+#include "ntqasyncimageio.h"
+#include "ntqpngio.h"
+#include "ntqmngio.h"
+#include "ntqjpegio.h"
+#include "ntqmap.h"
#include <private/qpluginmanager_p.h>
#include "qimageformatinterface_p.h"
-#include "qwmatrix.h"
-#include "qapplication.h"
-#include "qmime.h"
-#include "qdragobject.h"
+#include "ntqwmatrix.h"
+#include "ntqapplication.h"
+#include "ntqmime.h"
+#include "ntqdragobject.h"
#include <ctype.h>
#include <stdlib.h>
@@ -100,7 +100,7 @@
An entry in the color table is an RGB triplet encoded as a \c
uint. Use the \link ::qRed() qRed()\endlink, \link ::qGreen()
qGreen()\endlink and \link ::qBlue() qBlue()\endlink functions (\c
- qcolor.h) to access the components, and \link ::qRgb()
+ ntqcolor.h) to access the components, and \link ::qRgb()
qRgb\endlink to make an RGB triplet (see the TQColor class
documentation).
@@ -890,7 +890,7 @@ TQImage TQImage::copy(int x, int y, int w, int h, int conversion_flags) const
A color value is an RGB triplet. Use the \link ::qRed()
qRed()\endlink, \link ::qGreen() qGreen()\endlink and \link
- ::qBlue() qBlue()\endlink functions (defined in \c qcolor.h) to
+ ::qBlue() qBlue()\endlink functions (defined in \c ntqcolor.h) to
get the color value components.
\sa setColor() numColors() TQColor
@@ -902,7 +902,7 @@ TQImage TQImage::copy(int x, int y, int w, int h, int conversion_flags) const
Sets a color in the color table at index \a i to \a c.
A color value is an RGB triplet. Use the \link ::qRgb()
- qRgb()\endlink function (defined in \c qcolor.h) to make RGB
+ qRgb()\endlink function (defined in \c ntqcolor.h) to make RGB
triplets.
\sa color() setNumColors() numColors()
@@ -922,7 +922,7 @@ TQImage TQImage::copy(int x, int y, int w, int h, int conversion_flags) const
directly, because the pixel format depends on the byte order on
the underlying platform. Hint: use \link ::qRed() qRed()\endlink,
\link ::qGreen() qGreen()\endlink and \link ::qBlue()
- qBlue()\endlink, etc. (qcolor.h) to access the pixels.
+ qBlue()\endlink, etc. (ntqcolor.h) to access the pixels.
\warning If you are accessing 16-bpp image data, you must handle
endianness yourself. (TQt/Embedded only)
@@ -2373,7 +2373,7 @@ TQImage TQImage::convertBitOrder( Endian bitOrder ) const
return image;
}
// ### Candidate (renamed) for qcolor.h
static
bool isGray(TQRgb c)
{
@@ -3716,7 +3716,7 @@ static void swapPixel01( TQImage *image ) // 1-bpp: swap 0 and 1 pixels
*****************************************************************************/
/*!
- \class TQImageIO qimage.h
+ \class TQImageIO ntqimage.h
\brief The TQImageIO class contains parameters for loading and
saving images.
@@ -3954,7 +3954,7 @@ static TQImageHandler *get_image_handler( const char *format )
/*!
Defines an image I/O handler for the image format called \a
- format, which is recognized using the \link qregexp.html#details
+ format, which is recognized using the \link ntqregexp.html#details
regular expression\endlink \a header, read using \a readImage and
written using \a writeImage.
@@ -2373,7 +2373,7 @@ TQImage TQImage::convertBitOrder( Endian bitOrder ) const
return image;
}
-// ### Candidate (renamed) for qcolor.h
+// ### Candidate (renamed) for ntqcolor.h
static
bool isGray(TQRgb c)